@@ -7,7 +7,7 @@ use warnings;
 
 # VERSION
 
-our $VERSION = '3.10';
+our $VERSION = '3.18';
 
 # AUTHORITY
 
@@ -25,6 +25,7 @@ sub import {
   my %exports = (
     args => 1,
     array => 1,
+    arrayref => 1,
     assert => 1,
     bool => 1,
     box => 1,
@@ -34,6 +35,7 @@ sub import {
     caught => 1,
     chain => 1,
     check => 1,
+    clargs => 1,
     cli => 1,
     code => 1,
     config => 1,
@@ -46,6 +48,7 @@ sub import {
     float => 1,
     gather => 1,
     hash => 1,
+    hashref => 1,
     is_false => 1,
     is_true => 1,
     json => 1,
@@ -111,14 +114,16 @@ sub _qx {
 
 # FUNCTIONS
 
-sub args (@) {
-  my (@args) = @_;
+sub args ($;$@) {
+  my ($data, $code, @args) = @_;
 
-  return (!@args)
-    ? ({})
-    : ((@args == 1 && ref($args[0]) eq 'HASH')
-    ? (!%{$args[0]} ? {} : {%{$args[0]}})
-    : (@args % 2 ? {@args, undef} : {@args}));
+  require Venus::Args;
+
+  if (!$code) {
+    return Venus::Args->new($data);
+  }
+
+  return Venus::Args->new($data)->$code(@args);
 }
 
 sub array ($;$@) {
@@ -133,6 +138,14 @@ sub array ($;$@) {
   return Venus::Array->new($data)->$code(@args);
 }
 
+sub arrayref (@) {
+  my (@args) = @_;
+
+  return @args > 1
+    ? ([@args])
+    : ((ref $args[0] eq 'ARRAY') ? ($args[0]) : ([@args]));
+}
+
 sub assert ($$) {
   my ($data, $expr) = @_;
 
@@ -255,6 +268,18 @@ sub check ($$) {
   return Venus::Assert->new->expression($expr)->check($data);
 }
 
+sub clargs (@) {
+  my (@args) = @_;
+
+  my ($argv, $specs) = (@args > 1)
+    ? (map arrayref($_), @args)
+    : ([@ARGV], arrayref(@args));
+
+  return (
+    args($argv), opts($argv, 'reparse', $specs), vars({}),
+  );
+}
+
 sub cli (;$) {
   my ($data) = @_;
 
@@ -393,6 +418,16 @@ sub hash ($;$@) {
   return Venus::Hash->new($data)->$code(@args);
 }
 
+sub hashref (@) {
+  my (@args) = @_;
+
+  return @args > 1
+    ? ({(scalar(@args) % 2) ? (@args, undef) : @args})
+    : ((ref $args[0] eq 'HASH')
+    ? ($args[0])
+    : ({(scalar(@args) % 2) ? (@args, undef) : @args}));
+}
+
 sub is_false ($) {
   my ($data) = @_;
 
@@ -961,7 +996,7 @@ OO Standard Library for Perl 5
 
 =head1 VERSION
 
-3.10
+3.18
 
 =cut
 
@@ -972,6 +1007,7 @@ OO Standard Library for Perl 5
   use Venus qw(
     catch
     error
+    is_true
     raise
   );
 
@@ -981,16 +1017,16 @@ OO Standard Library for Perl 5
   };
 
   # boolean keywords
-  if ($result and $result eq false) {
-    true;
+  if (is_true $result) {
+    error;
   }
 
   # raise exceptions
-  if (false) {
+  if (is_true $result) {
     raise 'MyApp::Error';
   }
 
-  # and much more!
+  # boolean keywords, and more!
   true ne false;
 
 =cut
@@ -1097,11 +1133,12 @@ This package provides the following functions:
 
 =head2 args
 
-  args(Any @args) (HashRef)
+  args(ArrayRef $value, Str | CodeRef $code, Any @args) (Any)
 
-The args function takes a list of arguments and returns a hashref.
+The args function builds and returns a L<Venus::Args> object, or dispatches to
+the coderef or method provided.
 
-I<Since C<2.32>>
+I<Since C<3.10>>
 
 =over 4
 
@@ -1111,9 +1148,9 @@ I<Since C<2.32>>
 
   use Venus 'args';
 
-  my $args = args(content => 'example');
+  my $args = args ['--resource', 'users'];
 
-  # {content => "example"}
+  # bless({...}, 'Venus::Args')
 
 =back
 
@@ -1125,37 +1162,9 @@ I<Since C<2.32>>
 
   use Venus 'args';
 
-  my $args = args({content => 'example'});
+  my $args = args ['--resource', 'users'], 'indexed';
 
-  # {content => "example"}
-
-=back
-
-=over 4
-
-=item args example 3
-
-  package main;
-
-  use Venus 'args';
-
-  my $args = args('content');
-
-  # {content => undef}
-
-=back
-
-=over 4
-
-=item args example 4
-
-  package main;
-
-  use Venus 'args';
-
-  my $args = args('content', 'example', 'algorithm');
-
-  # {content => "example", algorithm => undef}
+  # {0 => '--resource', 1 => 'users'}
 
 =back
 
@@ -1200,6 +1209,58 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 arrayref
+
+  arrayref(Any @args) (ArrayRef)
+
+The arrayref function takes a list of arguments and returns a arrayref.
+
+I<Since C<3.10>>
+
+=over 4
+
+=item arrayref example 1
+
+  package main;
+
+  use Venus 'arrayref';
+
+  my $arrayref = arrayref(content => 'example');
+
+  # [content => "example"]
+
+=back
+
+=over 4
+
+=item arrayref example 2
+
+  package main;
+
+  use Venus 'arrayref';
+
+  my $arrayref = arrayref([content => 'example']);
+
+  # [content => "example"]
+
+=back
+
+=over 4
+
+=item arrayref example 3
+
+  package main;
+
+  use Venus 'arrayref';
+
+  my $arrayref = arrayref('content');
+
+  # ['content']
+
+=back
+
+=cut
+
 =head2 assert
 
   assert(Any $data, Str $expr) (Any)
@@ -1772,6 +1833,75 @@ I<Since C<2.40>>
 
 =cut
 
+=head2 clargs
+
+  clargs(ArrayRef $args, ArrayRef $spec) (Args, Opts, Vars)
+
+The clargs function accepts a single arrayref of L<Getopt::Long> specs, or an
+arrayref of arguments followed by an arrayref of L<Getopt::Long> specs, and
+returns a three element list of L<Venus::Args>, L<Venus::Opts>, and
+L<Venus::Vars> objects. If only a single arrayref is provided, the arguments
+will be taken from C<@ARGV>.
+
+I<Since C<3.10>>
+
+=over 4
+
+=item clargs example 1
+
+  package main;
+
+  use Venus 'clargs';
+
+  my ($args, $opts, $vars) = clargs;
+
+  # (
+  #   bless(..., 'Venus::Args'),
+  #   bless(..., 'Venus::Opts'),
+  #   bless(..., 'Venus::Vars')
+  # )
+
+=back
+
+=over 4
+
+=item clargs example 2
+
+  package main;
+
+  use Venus 'clargs';
+
+  my ($args, $opts, $vars) = clargs ['resource|r=s', 'help|h'];
+
+  # (
+  #   bless(..., 'Venus::Args'),
+  #   bless(..., 'Venus::Opts'),
+  #   bless(..., 'Venus::Vars')
+  # )
+
+=back
+
+=over 4
+
+=item clargs example 3
+
+  package main;
+
+  use Venus 'clargs';
+
+  my ($args, $opts, $vars) = clargs ['--resource', 'help'],
+    ['resource|r=s', 'help|h'];
+
+  # (
+  #   bless(..., 'Venus::Args'),
+  #   bless(..., 'Venus::Opts'),
+  #   bless(..., 'Venus::Vars')
+  # )
+
+=back
+
+=cut
+
 =head2 cli
 
   cli(ArrayRef $args) (Cli)
@@ -2329,6 +2459,72 @@ I<Since C<2.55>>
 
 =cut
 
+=head2 hashref
+
+  hashref(Any @args) (HashRef)
+
+The hashref function takes a list of arguments and returns a hashref.
+
+I<Since C<3.10>>
+
+=over 4
+
+=item hashref example 1
+
+  package main;
+
+  use Venus 'hashref';
+
+  my $hashref = hashref(content => 'example');
+
+  # {content => "example"}
+
+=back
+
+=over 4
+
+=item hashref example 2
+
+  package main;
+
+  use Venus 'hashref';
+
+  my $hashref = hashref({content => 'example'});
+
+  # {content => "example"}
+
+=back
+
+=over 4
+
+=item hashref example 3
+
+  package main;
+
+  use Venus 'hashref';
+
+  my $hashref = hashref('content');
+
+  # {content => undef}
+
+=back
+
+=over 4
+
+=item hashref example 4
+
+  package main;
+
+  use Venus 'hashref';
+
+  my $hashref = hashref('content', 'example', 'algorithm');
+
+  # {content => "example", algorithm => undef}
+
+=back
+
+=cut
+
 =head2 is_false
 
   is_false(Any $data) (Bool)
